markon-core 0.15.14

markon core - Mark it on.
docs.rs failed to build markon-core-0.15.14
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build: markon-core-0.13.10